summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorJannis Pohlmann <jannis.pohlmann@codethink.co.uk>2012-07-31 19:06:03 +0100
committerJannis Pohlmann <jannis.pohlmann@codethink.co.uk>2012-07-31 19:06:03 +0100
commitb6cdf99b810ea3646a1fecbb7d148bfc2804b1b3 (patch)
treee4d8541d07b77953ad7c92cc1ccaf51ec05a0282
parentf3ccbf4b6c1469beed53dbc8b1170db081f35206 (diff)
downloadnode-startup-controller-b6cdf99b810ea3646a1fecbb7d148bfc2804b1b3.tar.gz
Rename all remaining bits and pieces
-rw-r--r--CODING_STYLE12
-rw-r--r--README19
-rw-r--r--common/Makefile.am13
-rw-r--r--common/la-handler-dbus.xml4
-rw-r--r--common/nsm-consumer-dbus.xml32
-rw-r--r--common/nsm-lifecycle-control-dbus.xml24
-rw-r--r--docs/reference/node-startup-controller/Makefile.am2
-rw-r--r--docs/reference/node-startup-controller/legacy-app-handler.xml7
-rw-r--r--legacy-app-handler/Makefile.am2
-rw-r--r--legacy-app-handler/main.c4
-rw-r--r--node-startup-controller/busconf/Makefile.am8
-rw-r--r--node-startup-controller/busconf/org.genivi.NodeStartupController1.conf (renamed from node-startup-controller/busconf/org.genivi.BootManager1.conf)6
-rw-r--r--node-startup-controller/la-handler-service.c8
-rw-r--r--node-startup-controller/luc-starter.c15
-rw-r--r--nsm-dummy/Makefile.am4
-rw-r--r--nsm-dummy/com.contiautomotive.NodeStateManager.Consumer.service.in2
-rw-r--r--nsm-dummy/com.contiautomotive.NodeStateManager.LifecycleControl.service.in2
-rw-r--r--nsm-dummy/dbus/Makefile.am19
-rw-r--r--nsm-dummy/nsm-dummy.service.in2
-rw-r--r--nsm-dummy/systemd/Makefile.am18
-rw-r--r--tests/legacy-app-handler/Makefile.am2
-rwxr-xr-xtests/legacy-app-handler/legacy-app-handler-test9
-rw-r--r--tests/legacy-app-handler/legacy-app-handler-test1.service.in4
-rw-r--r--tests/legacy-app-handler/legacy-app-handler-test2.service.in4
-rw-r--r--tests/legacy-app-handler/legacy-app-handler-test3.service.in4
-rw-r--r--tests/node-startup-controller/Makefile.am4
-rwxr-xr-xtests/node-startup-controller/test-luc-handler32
27 files changed, 114 insertions, 148 deletions
diff --git a/CODING_STYLE b/CODING_STYLE
index 99f56cb..3137cae 100644
--- a/CODING_STYLE
+++ b/CODING_STYLE
@@ -1,13 +1,13 @@
-GENIVI Boot Manager Coding Style
-================================
+GENIVI Node Startup Controller Coding Style
+===========================================
This document intends to give information about the coding style to be
-used when contributing code to the GENIVI Boot Manager. It does not
-claim to be complete. Parts of it are taken or inspired from the Clutter
-coding style document.
+used when contributing code to the GENIVI Node Startup Controller. It
+does not claim to be complete. Parts of it are taken or inspired from
+the Clutter coding style document.
In the following, the most important requirements for writing consistent
-code for the GENIVI Boot Manager are explained.
+code for the GENIVI Node Startup Controller are explained.
Table of Contents:
* Copyright and License Header
diff --git a/README b/README
index dee6d30..9476f65 100644
--- a/README
+++ b/README
@@ -1,7 +1,8 @@
-GENIVI Boot Manager README
-==========================
+GENIVI Node Startup Controller README
+=====================================
-This is the official source repository of the GENIVI Boot Manager.
+This is the official source repository of the GENIVI Node Startup
+Controller.
At present, all relevant documentation for this project is available
in the GENIVI wiki on
@@ -20,7 +21,7 @@ Build Dependencies
------------------
The following libraries need to be installed in order to be able to
-build the boot manager:
+build the Node Startup Controller:
automotive-dlt >= 2.2.0
gio-2.0 >= 2.30.0
@@ -39,7 +40,7 @@ available for building:
Build Instructions
------------------
-In order to build the boot manager, run the following:
+In order to build the Node Startup Controller, run the following:
gtkdocize &&
autoreconf -ivf &&
@@ -74,7 +75,7 @@ For more information about all available configure options, run:
Install Instructions
--------------------
-To install the boot manager after having built it, run:
+To install the Node Startup Controller after having built it, run:
make install
@@ -82,12 +83,12 @@ To install the boot manager after having built it, run:
Testing Instructions
--------------------
-To run any test suites shipped with the boot manager, run:
+To run any test suites shipped with the Node Startup Controller, run:
make check
There may also be some post-install tests that can only be performed
-after installing the boot manager into the system. Those can be
-executed with:
+after installing the Node Startup Controller into the system. Those
+can be executed with:
make installcheck
diff --git a/common/Makefile.am b/common/Makefile.am
index ad53d6a..64f1fef 100644
--- a/common/Makefile.am
+++ b/common/Makefile.am
@@ -70,7 +70,9 @@ $(la_handler_built_sources): la-handler-dbus.xml Makefile
--interface-prefix org.genivi \
--c-namespace "" \
--generate-c-code la-handler-dbus \
- --annotate org.genivi.BootManager1.LegacyAppHandler org.gtk.GDBus.C.Name \
+ --annotate \
+ org.genivi.NodeStartupController1.LegacyAppHandler \
+ org.gtk.GDBus.C.Name \
LA_Handler $<
$(nsm_consumer_built_sources): nsm-consumer-dbus.xml Makefile
@@ -78,7 +80,8 @@ $(nsm_consumer_built_sources): nsm-consumer-dbus.xml Makefile
--interface-prefix com.contiautomotive.NodeStateManager \
--c-namespace "" \
--generate-c-code nsm-consumer-dbus \
- --annotate com.contiautomotive.NodeStateManager.Consumer \
+ --annotate \
+ com.contiautomotive.NodeStateManager.Consumer \
org.gtk.GDBus.C.Name NSM_Consumer $<
$(nsm_lifecycle_control_built_sources): nsm-lifecycle-control-dbus.xml Makefile
@@ -86,7 +89,8 @@ $(nsm_lifecycle_control_built_sources): nsm-lifecycle-control-dbus.xml Makefile
--interface-prefix com.contiautomotive.NodeStateManager \
--c-namespace "" \
--generate-c-code nsm-lifecycle-control-dbus \
- --annotate com.contiautomotive.NodeStateManager.LifecycleControl \
+ --annotate \
+ com.contiautomotive.NodeStateManager.LifecycleControl \
org.gtk.GDBus.C.Name NSM_Lifecycle_Control $<
$(shutdown_consumer_built_sources): shutdown-consumer-dbus.xml Makefile
@@ -94,5 +98,6 @@ $(shutdown_consumer_built_sources): shutdown-consumer-dbus.xml Makefile
--interface-prefix org.genivi \
--c-namespace "" \
--generate-c-code shutdown-consumer-dbus \
- --annotate com.contiautomotive.NodeStateManager.LifeCycleConsumer \
+ --annotate \
+ com.contiautomotive.NodeStateManager.LifeCycleConsumer \
org.gtk.GDBus.C.Name Shutdown_Consumer $<
diff --git a/common/la-handler-dbus.xml b/common/la-handler-dbus.xml
index 4f78c17..835d651 100644
--- a/common/la-handler-dbus.xml
+++ b/common/la-handler-dbus.xml
@@ -1,5 +1,5 @@
<?xml version="1.0" encoding="UTF-8"?>
-<node name="/org/genivi/BootManager1/LegacyAppHandler">
+<node name="/org/genivi/NodeStartupController1/LegacyAppHandler">
<!--
org.genivi.LegacyAppHandler1:
@short_description: Interface for registering legacy apps with the NSM
@@ -12,7 +12,7 @@
performs a shutdown it can shut down the application in reverse
order of their creation.
-->
- <interface name="org.genivi.BootManager1.LegacyAppHandler">
+ <interface name="org.genivi.NodeStartupController1.LegacyAppHandler">
<!--
Register:
@unit: An application unit filename.
diff --git a/common/nsm-consumer-dbus.xml b/common/nsm-consumer-dbus.xml
index 9ea9eb4..dd459f2 100644
--- a/common/nsm-consumer-dbus.xml
+++ b/common/nsm-consumer-dbus.xml
@@ -1,12 +1,12 @@
<?xml version="1.0" encoding="UTF-8"?>
<node>
<!--
- com.conti.NodeStateManager.Consumer:
- @short_description: Interface for testing the interaction between Boot
- Manager and Node State Manager.
- It is a summary of
- "com.conti.NodeStateManager.LifecycleControl" using
- only the methods needed to test Boot Manager.
+ com.contiautomotive.NodeStateManager.Consumer:
+ @short_description: Interface for testing the interaction between the
+ Node Startup Controller and the Node State Manager.
+ It is an excerpt of
+ "com.contiautomotive.NodeStateManager.LifecycleControl"
+ using only the methods needed to test the NSC.
-->
<interface name="com.contiautomotive.NodeStateManager.Consumer">
<!--
@@ -24,7 +24,8 @@
their DBUS object called NSMLifecycleRequest. This method will take one
parameter which is the Lifecycle Request (i.e. normal shutdown, fast
shutdown, runup). For an example of the required client interface
- please see the Boot Manager component who will be a client of the NSM.
+ please see the Node Startup Controller, which will be a client of
+ the NSM.
-->
<method name="RegisterShutdownClient">
<arg name="BusName" direction="in" type="s"/>
@@ -54,14 +55,19 @@
<arg name="ErrorCode" direction="out" type="i"/>
</method>
- <!--
+ <!--
LifecycleRequestComplete:
- @RequestId: The request Id of the called life cycle client. The value has been passed when "LifecycleRequest" was called.
- @Status: The result of the call to "LifecycleRequest". NsmErrorStatus_Ok: Request successfully processed. NsmErrorStatus_Error: An error occured while processing the "LifecycleRequest".
+ @RequestId: The request Id of the called life cycle client. The value
+ has been passed when "LifecycleRequest" was called.
+ @Status: The result of the call to "LifecycleRequest".
+ NsmErrorStatus_Ok: Request successfully processed.
+ NsmErrorStatus_Error: An error occured while processing
+ the "LifecycleRequest".
@ErrorCode: Return value passed to the caller, based upon NsmErrorStatus_e.
-
- The function has to be called by a "asynchrounous" lifecycle client, when he processed the "LifecycleRequest".
- -->
+
+ The function has to be called asynchrounously by a lifecycle client
+ when it has processed an earlier LifecycleRequest.
+ -->
<method name="LifecycleRequestComplete">
<arg name="RequestId" direction="in" type="u"/>
<arg name="Status" direction="in" type="i"/>
diff --git a/common/nsm-lifecycle-control-dbus.xml b/common/nsm-lifecycle-control-dbus.xml
index 4db0f38..9a85ffc 100644
--- a/common/nsm-lifecycle-control-dbus.xml
+++ b/common/nsm-lifecycle-control-dbus.xml
@@ -1,19 +1,19 @@
<?xml version="1.0" encoding="UTF-8"?>
<node>
<!--
- com.conti.NodeStateManager.LifecycleControl:
- @short_description: Interface for testing the interaction between Boot
- Manager and Node State Manager.
- It is a summary of
- "com.conti.NodeStateManager.LifecycleControl" using
- only the methods needed to test Boot Manager.
+ com.contiautomotive.NodeStateManager.LifecycleControl:
+ @short_description: Interface for testing the interaction between the
+ Node Startup Controller and the Node State Manager.
+ It is an excerpt of
+ "com.conti.NodeStateManager.LifecycleControl"
+ using only the methods needed to test the NSC.
-->
<interface name="com.contiautomotive.NodeStateManager.LifecycleControl">
<!--
SetNodeState:
@NodeStateId: The passed value will be based upon the enum
NSM_NodeState_e
- @ErrorCode
+ @ErrorCode:
The method is used by other applications to set the NodeState. When
this method is called to change the current NodeState a signal will be
@@ -29,11 +29,11 @@
@LucWanted: This will be a simple TRUE or FALSE to define whether the LUC
is wanted in the current Lifecycle
- This method will be called exclusivley by the Boot Manager to find out
- whether the LUC Applications should be started in the current
- Lifecycle. This is required whilst in certain Node Application Modes
- (i.e. Transport, Factory) we do not want the LUC Applications started.
- Internally the Node State Manager.
+ This method will be called exclusivley by the Node Startup Controller
+ to find out whether the LUC applications should be started in the
+ current lifecycle. This is required whilst in certain Node Application
+ Modes (i.e. Transport, Factory) we do not want the LUC applications
+ started.
-->
<method name="CheckLucRequired">
<arg name="LucWanted" direction="out" type="b"/>
diff --git a/docs/reference/node-startup-controller/Makefile.am b/docs/reference/node-startup-controller/Makefile.am
index 3d7a646..42c24ea 100644
--- a/docs/reference/node-startup-controller/Makefile.am
+++ b/docs/reference/node-startup-controller/Makefile.am
@@ -7,7 +7,7 @@ AUTOMAKE_OPTIONS = 1.6
DOC_MODULE=node-startup-controller
# Uncomment for versioned docs and specify the version of the module, e.g. '2'.
-DOC_MODULE_VERSION=$(BOOT_MANAGER_VERSION)
+DOC_MODULE_VERSION=$(NODE_STARTUP_CONTROLLER_VERSION)
# The top-level SGML file. You can change this if you want to.
DOC_MAIN_SGML_FILE=$(DOC_MODULE)-docs.xml
diff --git a/docs/reference/node-startup-controller/legacy-app-handler.xml b/docs/reference/node-startup-controller/legacy-app-handler.xml
index f87ab8d..eb38d7d 100644
--- a/docs/reference/node-startup-controller/legacy-app-handler.xml
+++ b/docs/reference/node-startup-controller/legacy-app-handler.xml
@@ -27,10 +27,9 @@
<title>Description</title>
<para>
<command>legacy-app-handler</command> is a helper binary which registers the legacy
- app <arg>unit</arg> with the boot manager, which in turn registers a shutdown client
- with the Node State Manager.
- This means that during the Node State Manager's shutdown cycle, it will shut down
- the legacy app as well.
+ app <arg>unit</arg> with the Node Startup Controller, which in turn registers a
+ shutdown client with the Node State Manager. This means that during the Node State
+ Manager's shutdown cycle, it will shut down the legacy app as well.
</para>
<refsect2>
<title>Arguments</title>
diff --git a/legacy-app-handler/Makefile.am b/legacy-app-handler/Makefile.am
index 3fcadd2..df723ec 100644
--- a/legacy-app-handler/Makefile.am
+++ b/legacy-app-handler/Makefile.am
@@ -1,7 +1,7 @@
# vi:set ts=8 sw=8 noet ai nocindent:
legacy_app_handlerdir = \
- $(libdir)/boot-manager-$(BOOT_MANAGER_VERSION_API)
+ $(libdir)/node-startup-controller-$(NODE_STARTUP_CONTROLLER_VERSION_API)
legacy_app_handler_PROGRAMS = \
legacy-app-handler
diff --git a/legacy-app-handler/main.c b/legacy-app-handler/main.c
index fafd9db..5a156c0 100644
--- a/legacy-app-handler/main.c
+++ b/legacy-app-handler/main.c
@@ -141,8 +141,8 @@ main (int argc,
service =
la_handler_proxy_new_for_bus_sync (G_BUS_TYPE_SYSTEM,
G_DBUS_PROXY_FLAGS_NONE,
- "org.genivi.BootManager1",
- "/org/genivi/BootManager1/LegacyAppHandler",
+ "org.genivi.NodeStartupController1",
+ "/org/genivi/NodeStartupController1/LegacyAppHandler",
NULL, &error);
/* abort if the proxy could not be created */
diff --git a/node-startup-controller/busconf/Makefile.am b/node-startup-controller/busconf/Makefile.am
index 6a03e55..02466de 100644
--- a/node-startup-controller/busconf/Makefile.am
+++ b/node-startup-controller/busconf/Makefile.am
@@ -1,9 +1,9 @@
# vi:set ts=8 sw=8 noet ai nocindent:
-boot_manager_confdir = $(sysconfdir)/dbus-1/system.d
+node_startup_controller_confdir = $(sysconfdir)/dbus-1/system.d
-boot_manager_conf_DATA = \
- org.genivi.BootManager1.conf
+node_startup_controller_conf_DATA = \
+ org.genivi.NodeStartupController1.conf
EXTRA_DIST = \
- org.genivi.BootManager1.conf
+ org.genivi.NodeStartupController1.conf
diff --git a/node-startup-controller/busconf/org.genivi.BootManager1.conf b/node-startup-controller/busconf/org.genivi.NodeStartupController1.conf
index b8c422f..f11fde5 100644
--- a/node-startup-controller/busconf/org.genivi.BootManager1.conf
+++ b/node-startup-controller/busconf/org.genivi.NodeStartupController1.conf
@@ -2,8 +2,8 @@
"http://www.freedesktop.org/standards/dbus/1.0/busconfig.dtd">
<busconfig>
<policy user="root">
- <allow own="org.genivi.BootManager1"/>
- <allow send_destination="org.genivi.BootManager1" />
- <allow receive_sender="org.genivi.BootManager1" />
+ <allow own="org.genivi.NodeStartupController1"/>
+ <allow send_destination="org.genivi.NodeStartupController1" />
+ <allow receive_sender="org.genivi.NodeStartupController1" />
</policy>
</busconfig>
diff --git a/node-startup-controller/luc-starter.c b/node-startup-controller/luc-starter.c
index 57121f8..637523d 100644
--- a/node-startup-controller/luc-starter.c
+++ b/node-startup-controller/luc-starter.c
@@ -566,18 +566,9 @@ luc_starter_start_groups_for_real (LUCStarter *starter)
&error);
if (error != NULL)
{
- if (error->code == G_IO_ERROR_NOT_FOUND)
- {
- DLT_LOG (controller_context, DLT_LOG_INFO,
- DLT_STRING ("Boot manager could not find the last user context"));
- }
- else
- {
- log_text = g_strdup_printf ("Error reading last user context: %s",
- error->message);
- DLT_LOG (controller_context, DLT_LOG_ERROR, DLT_STRING (log_text));
- g_free (log_text);
- }
+ log_text = g_strdup_printf ("Error reading last user context: %s", error->message);
+ DLT_LOG (controller_context, DLT_LOG_ERROR, DLT_STRING (log_text));
+ g_free (log_text);
g_error_free (error);
return;
}
diff --git a/nsm-dummy/Makefile.am b/nsm-dummy/Makefile.am
index b73f511..2fee15a 100644
--- a/nsm-dummy/Makefile.am
+++ b/nsm-dummy/Makefile.am
@@ -4,7 +4,7 @@ SUBDIRS = \
busconf
nsm_dummydir = \
- $(libdir)/boot-manager-$(BOOT_MANAGER_VERSION_API)
+ $(libdir)/node-startup-controller-$(NODE_STARTUP_CONTROLLER_VERSION_API)
nsm_dummy_PROGRAMS = \
nsm-dummy
@@ -46,7 +46,7 @@ nsm_dummy_LDADD = \
%.service: %.service.in
sed -e "s,\@libdir\@,$(libdir),g" \
- -e "s,\@BOOT_MANAGER_VERSION_API\@,$(BOOT_MANAGER_VERSION_API),g" < $< > $@
+ -e "s,\@NODE_STARTUP_CONTROLLER_VERSION_API\@,$(NODE_STARTUP_CONTROLLER_VERSION_API),g" < $< > $@
dbus_servicedir = $(datadir)/dbus-1/system-services
diff --git a/nsm-dummy/com.contiautomotive.NodeStateManager.Consumer.service.in b/nsm-dummy/com.contiautomotive.NodeStateManager.Consumer.service.in
index ff6f42d..def8ad1 100644
--- a/nsm-dummy/com.contiautomotive.NodeStateManager.Consumer.service.in
+++ b/nsm-dummy/com.contiautomotive.NodeStateManager.Consumer.service.in
@@ -1,4 +1,4 @@
[D-BUS Service]
Name=com.contiautomotive.NodeStateManager
SystemdService = nsm-dummy.service
-Exec=@libdir@/boot-manager-@BOOT_MANAGER_VERSION_API@/nsm-dummy
+Exec=@libdir@/node-startup-controller-@NODE_STARTUP_CONTROLLER_VERSION_API@/nsm-dummy
diff --git a/nsm-dummy/com.contiautomotive.NodeStateManager.LifecycleControl.service.in b/nsm-dummy/com.contiautomotive.NodeStateManager.LifecycleControl.service.in
index ff6f42d..def8ad1 100644
--- a/nsm-dummy/com.contiautomotive.NodeStateManager.LifecycleControl.service.in
+++ b/nsm-dummy/com.contiautomotive.NodeStateManager.LifecycleControl.service.in
@@ -1,4 +1,4 @@
[D-BUS Service]
Name=com.contiautomotive.NodeStateManager
SystemdService = nsm-dummy.service
-Exec=@libdir@/boot-manager-@BOOT_MANAGER_VERSION_API@/nsm-dummy
+Exec=@libdir@/node-startup-controller-@NODE_STARTUP_CONTROLLER_VERSION_API@/nsm-dummy
diff --git a/nsm-dummy/dbus/Makefile.am b/nsm-dummy/dbus/Makefile.am
deleted file mode 100644
index 224ab50..0000000
--- a/nsm-dummy/dbus/Makefile.am
+++ /dev/null
@@ -1,19 +0,0 @@
-# vi:set ts=8 sw=8 noet ai nocindent:
-
-servicedir = $(datadir)/dbus-1/system-services
-
-service_in_files = \
- com.contiautomotive.NodeStateManager.Consumer.service.in \
- com.contiautomotive.NodeStateManager.LifecycleControl.service.in
-
-service_DATA = $(service_in_files:.service.in=.service)
-
-%.service: %.service.in
- sed -e "s,\@libdir\@,$(libdir),g" \
- -e "s,\@BOOT_MANAGER_VERSION_API\@,$(BOOT_MANAGER_VERSION_API),g" < $< > $@
-
-CLEANFILES = \
- $(service_DATA)
-
-EXTRA_DIST = \
- $(service_in_files)
diff --git a/nsm-dummy/nsm-dummy.service.in b/nsm-dummy/nsm-dummy.service.in
index 72544aa..f328f49 100644
--- a/nsm-dummy/nsm-dummy.service.in
+++ b/nsm-dummy/nsm-dummy.service.in
@@ -1,5 +1,5 @@
[Service]
Type = dbus
BusName = com.contiautomotive.NodeStateManager
-ExecStart = @libdir@/boot-manager-@BOOT_MANAGER_VERSION_API@/nsm-dummy
+ExecStart = @libdir@/node-startup-controller-@NODE_STARTUP_CONTROLLER_VERSION_API@/nsm-dummy
WatchdogSec = 5
diff --git a/nsm-dummy/systemd/Makefile.am b/nsm-dummy/systemd/Makefile.am
deleted file mode 100644
index 8c674b3..0000000
--- a/nsm-dummy/systemd/Makefile.am
+++ /dev/null
@@ -1,18 +0,0 @@
-# vi:set ts=8 sw=8 noet ai nocindent:
-
-systemd_servicedir = $(libdir)/systemd/system
-
-systemd_service_in_files = \
- nsm-dummy.service.in
-
-systemd_service_DATA = $(systemd_service_in_files:.service.in=.service)
-
-%.service: %.service.in
- sed -e "s,\@libdir\@,$(libdir),g" \
- -e "s,\@BOOT_MANAGER_VERSION_API\@,$(BOOT_MANAGER_VERSION_API),g" < $< > $@
-
-CLEANFILES = \
- $(systemd_service_DATA)
-
-EXTRA_DIST = \
- $(systemd_service_in_files)
diff --git a/tests/legacy-app-handler/Makefile.am b/tests/legacy-app-handler/Makefile.am
index 7757305..3473ab2 100644
--- a/tests/legacy-app-handler/Makefile.am
+++ b/tests/legacy-app-handler/Makefile.am
@@ -12,7 +12,7 @@ noinst_DATA = \
%.service: %.service.in
sed -e "s,\@libdir\@,$(libdir),g" \
- -e "s,\@BOOT_MANAGER_VERSION_API\@,$(BOOT_MANAGER_VERSION_API),g" < $< > $@
+ -e "s,\@NODE_STARTUP_CONTROLLER_VERSION_API\@,$(NODE_STARTUP_CONTROLLER_VERSION_API),g" < $< > $@
CLEANFILES = \
*.service
diff --git a/tests/legacy-app-handler/legacy-app-handler-test b/tests/legacy-app-handler/legacy-app-handler-test
index 875b9d3..a8d8501 100755
--- a/tests/legacy-app-handler/legacy-app-handler-test
+++ b/tests/legacy-app-handler/legacy-app-handler-test
@@ -12,12 +12,13 @@ class TestService(dbus.service.Object):
def __init__(self, name):
bus_name = dbus.service.BusName(
- 'org.genivi.BootManager1.LegacyAppHandler.%s' % name,
+ 'org.genivi.NodeStartupController1.LegacyAppHandler.%s' % name,
bus=dbus.SystemBus())
- object_path = '/org/genivi/BootManager1/LegacyAppHandler/%s' % name
- dbus.service.Object.__init__(self, bus_name, object_path)
+ path = '/org/genivi/NodeStartupController1/LegacyAppHandler/%s' % name
+ dbus.service.Object.__init__(self, bus_name, path)
- @dbus.service.method('org.genivi.BootManager1.LegacyAppHandler.Test')
+ @dbus.service.method('org.genivi.NodeStartupController1.'
+ 'LegacyAppHandler.Test')
def hello(self):
return "Hello World!"
diff --git a/tests/legacy-app-handler/legacy-app-handler-test1.service.in b/tests/legacy-app-handler/legacy-app-handler-test1.service.in
index 2f95bc8..b1713ad 100644
--- a/tests/legacy-app-handler/legacy-app-handler-test1.service.in
+++ b/tests/legacy-app-handler/legacy-app-handler-test1.service.in
@@ -1,4 +1,4 @@
[Service]
-ExecStart = @libdir@/boot-manager-@BOOT_MANAGER_VERSION_API@/legacy-app-handler-test Test1
-ExecStartPost = @libdir@/boot-manager-@BOOT_MANAGER_VERSION_API@/legacy-app-handler \
+ExecStart = @libdir@/node-startup-controller-@NODE_STARTUP_CONTROLLER_VERSION_API@/legacy-app-handler-test Test1
+ExecStartPost = @libdir@/node-startup-controller-@NODE_STARTUP_CONTROLLER_VERSION_API@/legacy-app-handler \
--register --unit=legacy-app-handler-test1.service
diff --git a/tests/legacy-app-handler/legacy-app-handler-test2.service.in b/tests/legacy-app-handler/legacy-app-handler-test2.service.in
index 916e303..37dac10 100644
--- a/tests/legacy-app-handler/legacy-app-handler-test2.service.in
+++ b/tests/legacy-app-handler/legacy-app-handler-test2.service.in
@@ -1,4 +1,4 @@
[Service]
-ExecStart = @libdir@/boot-manager-@BOOT_MANAGER_VERSION_API@/legacy-app-handler-test Test2
-ExecStartPost = @libdir@/boot-manager-@BOOT_MANAGER_VERSION_API@/legacy-app-handler \
+ExecStart = @libdir@/node-startup-controller-@NODE_STARTUP_CONTROLLER_VERSION_API@/legacy-app-handler-test Test2
+ExecStartPost = @libdir@/node-startup-controller-@NODE_STARTUP_CONTROLLER_VERSION_API@/legacy-app-handler \
--register --unit=legacy-app-handler-test2.service
diff --git a/tests/legacy-app-handler/legacy-app-handler-test3.service.in b/tests/legacy-app-handler/legacy-app-handler-test3.service.in
index 27ea68a..2d8c8ab 100644
--- a/tests/legacy-app-handler/legacy-app-handler-test3.service.in
+++ b/tests/legacy-app-handler/legacy-app-handler-test3.service.in
@@ -1,4 +1,4 @@
[Service]
-ExecStart = @libdir@/boot-manager-@BOOT_MANAGER_VERSION_API@/legacy-app-handler-test Test3
-ExecStartPost = @libdir@/boot-manager-@BOOT_MANAGER_VERSION_API@/legacy-app-handler \
+ExecStart = @libdir@/node-startup-controller-@NODE_STARTUP_CONTROLLER_VERSION_API@/legacy-app-handler-test Test3
+ExecStartPost = @libdir@/node-startup-controller-@NODE_STARTUP_CONTROLLER_VERSION_API@/legacy-app-handler \
--register --unit=legacy-app-handler-test3.service
diff --git a/tests/node-startup-controller/Makefile.am b/tests/node-startup-controller/Makefile.am
index 0b4aecb..bb58c0b 100644
--- a/tests/node-startup-controller/Makefile.am
+++ b/tests/node-startup-controller/Makefile.am
@@ -18,8 +18,8 @@ EXTRA_DIST = \
export LUC_PATH = last-user-context
-export BOOT_MANAGER_CMD = \
- $(libdir)/boot-manager-$(BOOT_MANAGER_VERSION_API)/boot-manager
+export NODE_STARTUP_CONTROLLER_CMD = \
+ $(libdir)/node-startup-controller-$(NODE_STARTUP_CONTROLLER_VERSION_API)/node-startup-controller
noinst_PROGRAMS = \
gvariant-writer
diff --git a/tests/node-startup-controller/test-luc-handler b/tests/node-startup-controller/test-luc-handler
index 003877d..17558b3 100755
--- a/tests/node-startup-controller/test-luc-handler
+++ b/tests/node-startup-controller/test-luc-handler
@@ -19,9 +19,9 @@ compare_luc()
begin()
{
gdbus call --system \
- -d org.genivi.BootManager1 \
- -o /org/genivi/BootManager1/BootManager \
- -m org.genivi.BootManager1.BootManager.BeginLUCRegistration \
+ -d org.genivi.NodeStartupController1 \
+ -o /org/genivi/NodeStartupController1/NodeStartupController \
+ -m org.genivi.NodeStartupController1.NodeStartupController.BeginLUCRegistration \
&> /dev/null
}
@@ -30,9 +30,9 @@ begin()
register()
{
gdbus call --system \
- -d org.genivi.BootManager1 \
- -o /org/genivi/BootManager1/BootManager \
- -m org.genivi.BootManager1.BootManager.RegisterWithLUC \
+ -d org.genivi.NodeStartupController1 \
+ -o /org/genivi/NodeStartupController1/NodeStartupController \
+ -m org.genivi.NodeStartupController1.NodeStartupController.RegisterWithLUC \
"$1" &> /dev/null
}
@@ -41,9 +41,9 @@ register()
end()
{
gdbus call --system \
- -d org.genivi.BootManager1 \
- -o /org/genivi/BootManager1/BootManager \
- -m org.genivi.BootManager1.BootManager.FinishLUCRegistration \
+ -d org.genivi.NodeStartupController1 \
+ -o /org/genivi/NodeStartupController1/NodeStartupController \
+ -m org.genivi.NodeStartupController1.NodeStartupController.FinishLUCRegistration \
&> /dev/null
}
@@ -61,17 +61,17 @@ rm -f temp
rm -f "$LUC_PATH"
-# kill any existing instances of the boot manager
-skill -SIGKILL boot-manager 2>&1 >/dev/null
+# kill any existing instances of the Node Startup Controller
+skill -SIGKILL node-startup-controller 2>&1 >/dev/null
-# start the boot manager manually
-$BOOT_MANAGER_CMD &
+# start the Node Startup Controller manually
+$NODE_STARTUP_CONTROLLER_CMD &
-# wait for ten seconds, hoping the boot manager will become available
+# wait for ten seconds, hoping the Node Startup Controller will become available
sleep 2
-# kill the boot manager when the test script exits
-trap "skill -SIGKILL boot-manager 2>&1 >/dev/null" EXIT
+# kill the Node Startup Controller when the test script exits
+trap "skill -SIGKILL node-startup-controller 2>&1 >/dev/null" EXIT
# test a simple dictionary
diff --git a/node-startup-controller/la-handler-service.c b/node-startup-controller/la-handler-service.c
index edcd219..f2a9d93 100644
--- a/node-startup-controller/la-handler-service.c
+++ b/node-startup-controller/la-handler-service.c
@@ -188,7 +188,7 @@ la_handler_service_init (LAHandlerService *service)
service->index = 1;
/* the string that precedes the index in the shutdown client's object path */
- service->prefix = "/org/genivi/BootManager1/ShutdownConsumer";
+ service->prefix = "/org/genivi/NodeStartupController1/ShutdownConsumer";
/* initialize the association of shutdown client to units */
service->units_to_clients = g_hash_table_new_full (g_str_hash, g_str_equal,
@@ -337,7 +337,7 @@ la_handler_service_handle_register (LAHandler *interface,
else
{
/* create a new shutdown client and consumer for the unit */
- bus_name = "org.genivi.BootManager1";
+ bus_name = "org.genivi.NodeStartupController1";
object_path = g_strdup_printf ("%s/%u", service->prefix, service->index);
client = shutdown_client_new (bus_name, object_path, shutdown_mode, timeout);
consumer = shutdown_consumer_skeleton_new ();
@@ -614,10 +614,10 @@ la_handler_service_start (LAHandlerService *service,
g_return_val_if_fail (LA_HANDLER_IS_SERVICE (service), FALSE);
g_return_val_if_fail (error == NULL || *error == NULL, FALSE);
/* announce the org.genivi.BootManager1.LegacyAppHandler service on the bus */
return g_dbus_interface_skeleton_export (G_DBUS_INTERFACE_SKELETON (service->interface),
service->connection,
- "/org/genivi/BootManager1/LegacyAppHandler",
+ "/org/genivi/NodeStartupController1/LegacyAppHandler",
error);
}
@@ -614,10 +614,10 @@ la_handler_service_start (LAHandlerService *service,
g_return_val_if_fail (LA_HANDLER_IS_SERVICE (service), FALSE);
g_return_val_if_fail (error == NULL || *error == NULL, FALSE);
- /* announce the org.genivi.BootManager1.LegacyAppHandler service on the bus */
+ /* announce the org.genivi.NodeStartupController1.LegacyAppHandler service on the bus */
return g_dbus_interface_skeleton_export (G_DBUS_INTERFACE_SKELETON (service->interface),
service->connection,